==> gnome-panel-2.26.3-x86_64-4gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/fish/th/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/es/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/es/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/zh_CN/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/zh_CN/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/lib64 ; rm -rf libpanel-applet-2.so )
( cd usr/lib64 ; ln -sf libpanel-applet-2.so.0.2.57 libpanel-applet-2.so )
( cd usr/lib64 ; rm -rf libpanel-applet-2.so.0 )
( cd usr/lib64 ; ln -sf libpanel-applet-2.so.0.2.57 libpanel-applet-2.so.0 )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/clock.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/fish.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/panel-compatibility.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --direct --config-source="xml::etc/gconf/gconf.xml.defaults"       --load etc/gconf/schemas/panel-default-setup.entries >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/panel-general.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/panel-global.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/panel-object.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/panel-toplevel.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/window-list.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/workspace-switcher.schemas >/dev/null 2>&1
fi
# Preserve new configuration files
install_file() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

install_file etc/dbus-1/system.d/org.gnome.ClockApplet.Mechanism.conf.new

# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update icon cache
for i in gnome hicolor
do
        if [ -e usr/share/icons/$i/icon-theme.cache ]; then
                rm -f usr/share/icons/$i/icon-theme.cache
        fi
        usr/bin/gtk-update-icon-cache -f -q usr/share/icons/$i
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> gnome-panel-2.28.0-x86_64-2gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libpanel-applet-2.so.0 )
( cd usr/lib64 ; ln -sf libpanel-applet-2.so.0.2.60 libpanel-applet-2.so.0 )
( cd usr/lib64 ; rm -rf libpanel-applet-2.so )
( cd usr/lib64 ; ln -sf libpanel-applet-2.so.0.2.60 libpanel-applet-2.so )
( cd usr/share/gnome/help/fish/zh_CN/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/zh_CN/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/es/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/es/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fi/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fi/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/it/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/it/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/fi/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/fi/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/clock.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/fish.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/panel-compatibility.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/panel-general.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/panel-global.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/panel-object.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/panel-toplevel.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/window-list.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/workspace-switcher.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --direct    --config-source="xml::etc/gconf/gconf.xml.defaults"    --load etc/gconf/schemas/panel-default-setup.entries >/dev/null 2>&1
fi
# Preserve new configuration files
install_file() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Only needed for polkit
# install_file etc/dbus-1/system.d/org.gnome.ClockApplet.Mechanism.conf.new

# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update icon cache
for i in gnome hicolor
do
        if [ -e usr/share/icons/$i/icon-theme.cache ]; then
                rm -f usr/share/icons/$i/icon-theme.cache
        fi
        usr/bin/gtk-update-icon-cache -f -q usr/share/icons/$i
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
